// =============================================================================
// Date masks
// =============================================================================

// Every mask is 7 days longer to handle cross-year weekly periods.

pub(crate) type WdayMask = [u8; 7 * 55];
pub(crate) type Mask365 = [u8; 365 + 7];
pub(crate) type Mask366 = [u8; 366 + 7];
pub(crate) type Mask365Signed = [i8; 365 + 7];
pub(crate) type Mask366Signed = [i8; 366 + 7];
pub(crate) type MonthRangeMask = [u16; 13];

const M365: Mask365 = [
    // 31
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    // 28
    2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
    // 31
    3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
    // 30
    4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
    // 31
    5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
    // 30
    6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
    // 31
    7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
    // 31
    8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8,
    // 30
    9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9,
    // 31
    10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10,
    10, 10, 10, 10, 10, 10, 10,
    // 30 -----------------------------------------------------------------------------------------
    11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11,
    11, 11, 11, 11, 11, 11,
    // 31 -----------------------------------------------------------------------------------------
    12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12,
    12, 12, 12, 12, 12, 12, 12,
    // 7 ------------------------------------------------------------------------------------------
    1, 1, 1, 1, 1, 1, 1,
];
const MDAY365: Mask365Signed = [
    // 31
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30, 31,
    // 28 -----------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28,
    // 31 ---------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30, 31,
    // 30 ---------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30,
    // 31 ---------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30, 31,
    // 30 ---------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30,
    // 31 ---------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30, 31,
    // 31 ---------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30, 31,
    // 30 ---------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30,
    // 31 ---------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30, 31,
    // 30 -----------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30,
    // 31 -----------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30, 31,
    // 7 -----------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7,
];
const NMDAY365: Mask365Signed = [
    // 31
    -31, -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13,
    -12, -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 28 -----------------------------------------------------------------------------------------
    -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13, -12, -11, -10,
    -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 31 ---------------------------------------------------------------------------------------
    -31, -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13,
    -12, -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 30 ---------------------------------------------------------------------------------------
    -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13, -12,
    -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 31 ---------------------------------------------------------------------------------------
    -31, -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13,
    -12, -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 30 ---------------------------------------------------------------------------------------
    -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13, -12,
    -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 31 ---------------------------------------------------------------------------------------
    -31, -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13,
    -12, -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 31 ---------------------------------------------------------------------------------------
    -31, -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13,
    -12, -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 30 ---------------------------------------------------------------------------------------
    -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13, -12,
    -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 31 ---------------------------------------------------------------------------------------
    -31, -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13,
    -12, -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 30 -----------------------------------------------------------------------------------------
    -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13, -12,
    -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 31 -----------------------------------------------------------------------------------------
    -31, -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13,
    -12, -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 7 -----------------------------------------------------------------------------------------
    -31, -30, -29, -28, -27, -26, -25,
];
const M365_RANGE: MonthRangeMask = [0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334, 365];

const M366: Mask366 = [
    // 31
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    // 29
    2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
    // 31
    3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
    // 30
    4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
    // 31
    5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
    // 30
    6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
    // 31
    7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
    // 31
    8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8,
    // 30
    9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9,
    // 31
    10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10,
    10, 10, 10, 10, 10, 10, 10,
    // 30 -----------------------------------------------------------------------------------------
    11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11,
    11, 11, 11, 11, 11, 11,
    // 31 -----------------------------------------------------------------------------------------
    12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12,
    12, 12, 12, 12, 12, 12, 12,
    // 7 ------------------------------------------------------------------------------------------
    1, 1, 1, 1, 1, 1, 1,
];
const MDAY366: Mask366Signed = [
    // 31
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30, 31,
    // 29 -----------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29,
    // 31 ---------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30, 31,
    // 30 ---------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30,
    // 31 ---------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30, 31,
    // 30 ---------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30,
    // 31 ---------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30, 31,
    // 31 ---------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30, 31,
    // 30 ---------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30,
    // 31 ---------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30, 31,
    // 30 -----------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30,
    // 31 -----------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
    27, 28, 29, 30, 31,
    // 7 -----------------------------------------------------------------------------------------
    1, 2, 3, 4, 5, 6, 7,
];
const M366_RANGE: MonthRangeMask = [0, 31, 60, 91, 121, 152, 182, 213, 244, 274, 305, 335, 366];
const NMDAY366: Mask366Signed = [
    // 31
    -31, -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13,
    -12, -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 29 -----------------------------------------------------------------------------------------
    -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13, -12, -11,
    -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 31 ---------------------------------------------------------------------------------------
    -31, -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13,
    -12, -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 30 ---------------------------------------------------------------------------------------
    -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13, -12,
    -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 31 ---------------------------------------------------------------------------------------
    -31, -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13,
    -12, -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 30 ---------------------------------------------------------------------------------------
    -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13, -12,
    -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 31 ---------------------------------------------------------------------------------------
    -31, -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13,
    -12, -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 31 ---------------------------------------------------------------------------------------
    -31, -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13,
    -12, -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 30 ---------------------------------------------------------------------------------------
    -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13, -12,
    -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 31 ---------------------------------------------------------------------------------------
    -31, -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13,
    -12, -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 30 -----------------------------------------------------------------------------------------
    -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13, -12,
    -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 31 -----------------------------------------------------------------------------------------
    -31, -30, -29, -28, -27, -26, -25, -24, -23, -22, -21, -20, -19, -18, -17, -16, -15, -14, -13,
    -12, -11, -10, -9, -8, -7, -6, -5, -4, -3, -2, -1,
    // 7 -----------------------------------------------------------------------------------------
    -31, -30, -29, -28, -27, -26, -25,
];
const WDAY: WdayMask = [
    0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3,
    4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0,
    1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4,
    5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1,
    2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5,
    6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2,
    3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6,
    0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3,
    4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0,
    1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4,
    5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1,
    2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5, 6, 0, 1, 2, 3, 4, 5,
    6,
];

#[derive(Clone)]
pub(crate) struct Masks {
    pub weekday: WdayMask,
    pub month_365: Mask365,
    pub month_365_range: MonthRangeMask,
    pub month_366: Mask366,
    pub month_366_range: MonthRangeMask,
    pub month_day_365: Mask365Signed,
    pub month_day_366: Mask366Signed,
    pub neg_month_day_365: Mask365Signed,
    pub neg_month_day_366: Mask366Signed,
}

pub(crate) const MASKS: Masks = Masks {
    weekday: WDAY,
    month_365: M365,
    month_365_range: M365_RANGE,
    month_366: M366,
    month_366_range: M366_RANGE,
    month_day_365: MDAY365,
    month_day_366: MDAY366,
    neg_month_day_365: NMDAY365,
    neg_month_day_366: NMDAY366,
};

// impl Default for Masks {
//     fn default() -> Self {
//         let m28: Vec<usize> = (1..29).collect();
//         let m29: Vec<usize> = (1..30).collect();
//         let m30: Vec<usize> = (1..31).collect();
//         let m31: Vec<usize> = (1..32).collect();

//         let nm28: Vec<isize> = (-28..0).collect();
//         let nm29: Vec<isize> = (-29..0).collect();
//         let nm30: Vec<isize> = (-30..0).collect();
//         let nm31: Vec<isize> = (-31..0).collect();

//         Self {
//             wday: vec![(0..7).collect::<Vec<usize>>(); 55]
//                 .into_iter()
//                 .flatten()
//                 .collect(),
//             m365: vec![
//                 vec![1; 31],
//                 vec![2; 28],
//                 vec![3; 31],
//                 vec![4; 30],
//                 vec![5; 31],
//                 vec![6; 30],
//                 vec![7; 31],
//                 vec![8; 31],
//                 vec![9; 30],
//                 vec![10; 31],
//                 vec![11; 30],
//                 vec![12; 31],
//                 vec![1; 7],
//             ]
//             .into_iter()
//             .flatten()
//             .collect(),
//             m365range: vec![0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334, 365],
//             mday366: vec![
//                 m31.clone(),
//                 m29,
//                 m31.clone(),
//                 m30.clone(),
//                 m31.clone(),
//                 m30.clone(),
//                 m31.clone(),
//                 m31.clone(),
//                 m30.clone(),
//                 m31.clone(),
//                 m30.clone(),
//                 m31.clone(),
//                 Vec::from(&m31[0..7]),
//             ]
//             .into_iter()
//             .flatten()
//             .map(|d| d as isize)
//             .collect(),
//             m366range: vec![0, 31, 60, 91, 121, 152, 182, 213, 244, 274, 305, 335, 366],
//             mday365: vec![
//                 m31.clone(),
//                 m28,
//                 m31.clone(),
//                 m30.clone(),
//                 m31.clone(),
//                 m30.clone(),
//                 m31.clone(),
//                 m31.clone(),
//                 m30.clone(),
//                 m31.clone(),
//                 m30,
//                 m31.clone(),
//                 Vec::from(&m31[0..7]),
//             ]
//             .into_iter()
//             .flatten()
//             .map(|d| d as isize)
//             .collect(),
//             m366: vec![
//                 vec![1; 31],
//                 vec![2; 29],
//                 vec![3; 31],
//                 vec![4; 30],
//                 vec![5; 31],
//                 vec![6; 30],
//                 vec![7; 31],
//                 vec![8; 31],
//                 vec![9; 30],
//                 vec![10; 31],
//                 vec![11; 30],
//                 vec![12; 31],
//                 vec![1; 7],
//             ]
//             .into_iter()
//             .flatten()
//             .collect(),
//             nmday365: vec![
//                 nm31.clone(),
//                 nm28,
//                 nm31.clone(),
//                 nm30.clone(),
//                 nm31.clone(),
//                 nm30.clone(),
//                 nm31.clone(),
//                 nm31.clone(),
//                 nm30.clone(),
//                 nm31.clone(),
//                 nm30.clone(),
//                 nm31.clone(),
//                 Vec::from(&nm31[0..7]),
//             ]
//             .into_iter()
//             .flatten()
//             .collect(),
//             nmday366: vec![
//                 nm31.clone(),
//                 nm29,
//                 nm31.clone(),
//                 nm30.clone(),
//                 nm31.clone(),
//                 nm30.clone(),
//                 nm31.clone(),
//                 nm31.clone(),
//                 nm30.clone(),
//                 nm31.clone(),
//                 nm30,
//                 nm31.clone(),
//                 Vec::from(&nm31[0..7]),
//             ]
//             .into_iter()
//             .flatten()
//             .collect(),
//         }
//     }
// }
